summaryrefslogtreecommitdiffstats
path: root/PRESUBMIT.py
diff options
context:
space:
mode:
authorsaintlou@chromium.org <saintlou@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-08-10 00:14:45 +0000
committersaintlou@chromium.org <saintlou@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-08-10 00:14:45 +0000
commit0be9553a09724d6008d74a4fcaa10dcfb45c7268 (patch)
tree5afc7e6003e11f8f3cc493e9e8443616c64af13a /PRESUBMIT.py
parentcf5f1a6f9eafb91e40c7c0c21d89a8f1fab7015e (diff)
downloadchromium_src-0be9553a09724d6008d74a4fcaa10dcfb45c7268.zip
chromium_src-0be9553a09724d6008d74a4fcaa10dcfb45c7268.tar.gz
chromium_src-0be9553a09724d6008d74a4fcaa10dcfb45c7268.tar.bz2
Over the last week (or so) a couple of CLs had to be reverted because developers had not tested win_aura, specifically:
1. The default trybot rules don't include win_aura in enough cases 2. The CQ did not build win_aura BUG=141701 TBR=sky Review URL: https://chromiumcodereview.appspot.com/10831242 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@150950 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'PRESUBMIT.py')
-rw-r--r--PRESUBMIT.py9
1 files changed, 6 insertions, 3 deletions
diff --git a/PRESUBMIT.py b/PRESUBMIT.py
index 9df2cfd..0eefbff 100644
--- a/PRESUBMIT.py
+++ b/PRESUBMIT.py
@@ -592,8 +592,11 @@ def GetPreferredTrySlaves(project, change):
'android']
# Match things like path/aura/file.cc and path/file_aura.cc.
- # Same for chromeos.
- if any(re.search('[/_](aura|chromeos)', f) for f in files):
- trybots += ['linux_chromeos', 'linux_chromeos_clang:compile']
+ # Same for ash and chromeos.
+ if any(re.search('[/_](ash|aura)', f) for f in files):
+ trybots += ['linux_chromeos', 'linux_chromeos_clang:compile', 'win_aura']
+ else:
+ if any(re.search('[/_]chromeos', f) for f in files):
+ trybots += ['linux_chromeos', 'linux_chromeos_clang:compile']
return trybots